@@ -1,7 +1,7 @@
 /*
  *  alarmcalendar.cpp  -  KAlarm calendar file access
  *  Program:  kalarm
- *  Copyright © 2001-2018 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@
 
 #include <QTemporaryFile>
 #include <QStandardPaths>
-#include <QTimeZone>
+#include <QFileDialog>
 #include "kalarm_debug.h"
 
 using namespace Akonadi;
@@ -55,6 +55,7 @@ static const Collection::Id DISPLAY_COL_ID = -1;   // collection ID used for dis
 
 AlarmCalendar* AlarmCalendar::mResourcesCalendar = nullptr;
 AlarmCalendar* AlarmCalendar::mDisplayCalendar = nullptr;
+QUrl           AlarmCalendar::mLastImportUrl;
 
 
 /******************************************************************************
@@ -595,8 +596,8 @@ void AlarmCalendar::slotEventsToBeRemoved(const AkonadiModel::EventList& events)
 bool AlarmCalendar::importAlarms(QWidget* parent, Collection* collection)
 {
     qCDebug(KALARM_LOG) << "AlarmCalendar::importAlarms";
-    QUrl url = KFileDialog::getOpenUrl(QUrl(QStringLiteral("filedialog:///importalarms")),
-                                       QStringLiteral("*.vcs *.ics|%1").arg(i18nc("@info", "Calendar Files")), parent);
+    const QUrl url = QFileDialog::getOpenFileUrl(parent, QString(), mLastImportUrl,
+                                                 QStringLiteral("%1 (*.vcs *.ics)").arg(i18nc("@info", "Calendar Files")));
     if (url.isEmpty())
     {
         qCCritical(KALARM_LOG) << "AlarmCalendar::importAlarms: Empty URL";
@@ -607,6 +608,7 @@ bool AlarmCalendar::importAlarms(QWidget* parent, Collection* collection)
         qCDebug(KALARM_LOG) << "AlarmCalendar::importAlarms: Invalid URL";
         return false;
     }
+    mLastImportUrl = url.adjusted(QUrl::RemoveFilename);
     qCDebug(KALARM_LOG) << "AlarmCalendar::importAlarms:" << url.toDisplayString();
 
     bool success = true;
@@ -906,6 +908,7 @@ bool AlarmCalendar::addEvent(KAEvent& evnt, QWidget* promptParent, bool useEvent
                 if (mEventType == CalEvent::EMPTY)
                     break;
                 // fall through to default
+                Q_FALLTHROUGH();
             default:
                 return false;
         }
