@@ -1,7 +1,7 @@
 /*
  *  alarmlistview.h  -  widget showing list of alarms
  *  Program:  kalarm
- *  Copyright © 2007 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2007,2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -34,12 +34,20 @@ class AlarmListView : public EventListView
     public:
         explicit AlarmListView(const QByteArray& configGroup, QWidget* parent = nullptr);
         void        setModel(QAbstractItemModel*) override;
-        void        selectTimeColumns(bool time, bool timeTo);
+        QList<bool> columnsVisible() const;
+        void        setColumnsVisible(const QList<bool>& show);
+
+    Q_SIGNALS:
+        void        columnsVisibleChanged();
 
     private Q_SLOTS:
         void        sectionMoved();
+        void        headerContextMenuRequested(const QPoint&);
 
     private:
+        void        showHideColumn(QMenu&, QAction*);
+        void        enableTimeColumns(QMenu*);
+
         QByteArray  mConfigGroup;
 };
 
