@@ -110,13 +110,14 @@ void Find::display()
 
         // Alarm types
         QVBoxLayout* layout = new QVBoxLayout(kalarmWidgets);
-        layout->setMargin(0);
-        layout->setSpacing(qApp->style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+        layout->setContentsMargins(0, 0, 0, 0);
+        layout->setSpacing(QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
         QGroupBox* group = new QGroupBox(i18nc("@title:group", "Alarm Type"), kalarmWidgets);
         layout->addWidget(group);
         QGridLayout* grid = new QGridLayout(group);
-        grid->setMargin(qApp->style()->pixelMetric(QStyle::PM_DefaultChildMargin));
-        grid->setSpacing(qApp->style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+        int dcm = QApplication::style()->pixelMetric(QStyle::PM_DefaultChildMargin);
+        grid->setContentsMargins(dcm, dcm, dcm, dcm);
+        grid->setSpacing(QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
         grid->setColumnStretch(1, 1);
 
         // Live & archived alarm selection
@@ -215,6 +216,7 @@ void Find::display()
                     break;
                 }
                 // fall through to ACT_DISPLAY_COMMAND
+                Q_FALLTHROUGH();
             case KAEvent::ACT_DISPLAY_COMMAND:
             default:
                 text = true;
@@ -373,6 +375,7 @@ void Find::findNext(bool forward, bool checkEnd, bool fromCurrent)
                     break;
                 }
                 // fall through to ACT_DISPLAY_COMMAND
+                Q_FALLTHROUGH();
             case KAEvent::ACT_DISPLAY_COMMAND:
                 if (!(mOptions & FIND_MESSAGE))
                     break;
