@@ -65,16 +65,6 @@ using namespace KCalCore;
 #include <KIO/StatJob>
 #include <KJobWidgets>
 #include <kfileitem.h>
-#include <ktoolinvocation.h>
-
-#if KDEPIM_HAVE_X11
-#include <kwindowsystem.h>
-#include <kwindowinfo.h>
-#include <kxmessages.h>
-#include <kstartupinfo.h>
-#include <netwm.h>
-#include <QX11Info>
-#endif
 
 #include <QAction>
 #include <QDir>
@@ -87,11 +77,6 @@ using namespace KCalCore;
 #include <QStandardPaths>
 #include "kalarm_debug.h"
 
-#if KDEPIM_HAVE_X11
-#include <X11/Xlib.h>
-#include <X11/Xutil.h>
-#endif
-
 using namespace Akonadi;
 
 
@@ -138,7 +123,7 @@ const QLatin1String KORG_DBUS_IFACE("org.kde.korganizer.Korganizer");
 #define       KORG_DBUS_LOAD_PATH       "/korganizer_PimApplication"
 //const QLatin1String KORG_DBUS_WINDOW_PATH("/korganizer/MainWindow_1");
 const QLatin1String KORG_MIME_TYPE("application/x-vnd.akonadi.calendar.event");
-const QLatin1String KORGANIZER_UID("-korg");
+const QLatin1String KORGANIZER_UID("korg-");
 
 const QLatin1String ALARM_OPTS_FILE("alarmopts");
 const char*         DONT_SHOW_ERRORS_GROUP = "DontShowErrors";
@@ -1393,20 +1378,20 @@ void refreshAlarmsIfQueued()
 
 /******************************************************************************
 * Start KMail if it isn't already running, optionally minimised.
-* Reply = reason for failure to run KMail (which may be the empty string)
+* Reply = reason for failure to run KMail
 *       = null string if success.
 */
-QString runKMail(bool minimise)
+QString runKMail()
 {
     QDBusReply<bool> reply = QDBusConnection::sessionBus().interface()->isServiceRegistered(KMAIL_DBUS_SERVICE);
     if (!reply.isValid()  ||  !reply.value())
     {
         // Program is not already running, so start it
         QString errmsg;
-        if (minimise  &&  Private::startKMailMinimised())
-            return QString();
-        if (KToolInvocation::startServiceByDesktopName(QStringLiteral("org.kde.kmail2"), QString(), &errmsg))
+        QDBusReply<void> startReply = QDBusConnection::sessionBus().interface()->startService(KMAIL_DBUS_SERVICE);
+        if (!startReply.isValid())
         {
+            QString errmsg = startReply.error().message();
             qCCritical(KALARM_LOG) << "Couldn't start KMail (" << errmsg << ")";
             return xi18nc("@info", "Unable to start <application>KMail</application><nl/>(<message>%1</message>)", errmsg);
         }
@@ -1414,92 +1399,6 @@ QString runKMail(bool minimise)
     return QString();
 }
 
-/******************************************************************************
-* Start KMail, minimised.
-* This code is taken from kstart in kdebase.
-*/
-bool Private::startKMailMinimised()
-{
-#if KDEPIM_HAVE_X11
-    NETRootInfo i(QX11Info::connection(), NET::Supported, NET::Properties2());
-    if (i.isSupported(NET::WM2KDETemporaryRules))
-    {
-        qCDebug(KALARM_LOG) << "startKMailMinimised: using rules";
-        KXMessages msg;
-        QString message = QLatin1String("wmclass=kmail\nwmclassmatch=1\n"  // 1 = exact match
-                          "wmclasscomplete=false\n"
-                          "minimize=true\nminimizerule=3\n"
-                          "type=") + QString().setNum(NET::Normal) + QLatin1String("\ntyperule=2");
-        msg.broadcastMessage("_KDE_NET_WM_TEMPORARY_RULES", message, -1);
-        QCoreApplication::processEvents();
-    }
-    else
-    {
-        // Connect to window add to get the NEW windows
-        qCDebug(KALARM_LOG) << "startKMailMinimised: connecting to window add";
-        connect(KWindowSystem::self(), &KWindowSystem::windowAdded, instance(), &Private::windowAdded);
-    }
-    // Propagate the app startup notification info to the started app.
-    // We are not using KApplication, so the env remained set.
-    KStartupInfoId id = KStartupInfo::currentStartupIdEnv();
-    KProcess* proc = new KProcess;
-    (*proc) << QStringLiteral("kmail");
-    int pid = proc->startDetached();
-    if (!pid)
-    {
-        KStartupInfo::sendFinish(id); // failed to start
-        return false;
-    }
-    KStartupInfoData data;
-    data.addPid(pid);
-    data.setName(QLatin1String("kmail"));
-    data.setBin(QLatin1String("kmail"));
-    KStartupInfo::sendChange(id, data);
-    return true;
-#else
-    return false;
-#endif
-}
-
-/******************************************************************************
-* Called when a window is created, to minimise it.
-* This code is taken from kstart in kdebase.
-*/
-void Private::windowAdded(WId w)
-{
-#if KDEPIM_HAVE_X11
-    static const NET::WindowTypes SUPPORTED_TYPES =
-                             NET::NormalMask | NET::DesktopMask | NET::DockMask
-                           | NET::ToolbarMask | NET::MenuMask | NET::DialogMask
-                           | NET::OverrideMask | NET::TopMenuMask | NET::UtilityMask | NET::SplashMask;
-    KWindowInfo kwinfo(w, NET::WMWindowType | NET::WMName);
-    if (kwinfo.windowType(SUPPORTED_TYPES) == NET::TopMenu
-    ||  kwinfo.windowType(SUPPORTED_TYPES) == NET::Toolbar
-    ||  kwinfo.windowType(SUPPORTED_TYPES) == NET::Desktop)
-        return;   // always ignore these window types
-
-    Display* display = QX11Info::display();
-    XWithdrawWindow(display, w, QX11Info::appScreen());
-    QCoreApplication::processEvents();
-
-    NETWinInfo info(QX11Info::connection(), w, QX11Info::appRootWindow(), NET::WMState, NET::Properties2());
-    XWMHints* hints = XGetWMHints(display, w);
-    if (hints)
-    {
-        hints->flags |= StateHint;
-        hints->initial_state = IconicState;
-        XSetWMHints(display, w, hints);
-        XFree(hints);
-    }
-    info.setWindowType(NET::Normal);
-
-    XSync(display, False);
-    XMapWindow(display, w);
-    XSync(display, False);
-    QCoreApplication::processEvents();
-#endif
-}
-
 /******************************************************************************
 * The "Don't show again" option for error messages is personal to the user on a
 * particular computer. For example, he may want to inhibit error messages only
@@ -1857,7 +1756,7 @@ KAlarm::UpdateResult sendToKOrganizer(const KAEvent& event)
     Event::Ptr kcalEvent(new KCalCore::Event);
     event.updateKCalEvent(kcalEvent, KAEvent::UID_IGNORE);
     // Change the event ID to avoid duplicating the same unique ID as the original event
-    QString uid = uidKOrganizer(event.id());
+    const QString uid = uidKOrganizer(event.id());
     kcalEvent->setUid(uid);
     kcalEvent->clearAlarms();
     QString userEmail;
@@ -1886,21 +1785,20 @@ KAlarm::UpdateResult sendToKOrganizer(const KAEvent& event)
         default:
             break;
     }
-    Person person(QString(), userEmail);
+    const Person person(QString(), userEmail);
     kcalEvent->setOrganizer(person);
     kcalEvent->setDuration(Duration(Preferences::kOrgEventDuration() * 60, Duration::Seconds));
 
     // Translate the event into string format
     ICalFormat format;
     format.setTimeZone(Preferences::timeSpecAsZone());
-    QString iCal = format.toICalString(kcalEvent);
+    const QString iCal = format.toICalString(kcalEvent);
 
     // Send the event to KOrganizer
     KAlarm::UpdateResult status = runKOrganizer();   // start KOrganizer if it isn't already running, and create its D-Bus interface
     if (status != KAlarm::UPDATE_OK)
         return status;
-    QList<QVariant> args;
-    args << iCal;
+    const QList<QVariant> args{iCal};
     QDBusReply<bool> reply = korgInterface->callWithArgumentList(QDBus::Block, QStringLiteral("addIncidence"), args);
     if (!reply.isValid())
     {
@@ -1931,7 +1829,7 @@ KAlarm::UpdateResult sendToKOrganizer(const KAEvent& event)
 KAlarm::UpdateResult deleteFromKOrganizer(const QString& eventID)
 {
     const QString newID = uidKOrganizer(eventID);
-    new CollectionSearch(KORG_MIME_TYPE, newID, true);  // this auto-deletes when complete
+    new CollectionSearch(KORG_MIME_TYPE, QString(), newID, true);  // this auto-deletes when complete
     // Ignore errors
     return KAlarm::UpdateResult(KAlarm::UPDATE_OK);
 }
@@ -1991,11 +1889,10 @@ KAlarm::UpdateResult runKOrganizer()
 */
 QString uidKOrganizer(const QString& id)
 {
+    if (id.startsWith(KORGANIZER_UID))
+        return id;
     QString result = id;
-    int i = result.lastIndexOf(QLatin1Char('-'));
-    if (i < 0)
-        i = result.length();
-    return result.insert(i, KORGANIZER_UID);
+    return result.insert(0, KORGANIZER_UID);
 }
 
 } // namespace
